import java.awt.image.BufferedImage;
import java.awt.image.ImageObserver;
import java.awt.Graphics;
import java.awt.Color;

public class FrameFilter implements BufferedImageFilter2, ParameterizedFilter {
	private final IntFilterParam thicknessParam
		= new IntFilterParam("Thickness", 1, Integer.MAX_VALUE, 10);
	
	private final FilterParam[] params = new FilterParam[] {
		thicknessParam
	};
	
	// ### FILTER ###
	
	public void filter(BufferedImage inImg, BufferedImage outImg) {
		Graphics g = outImg.getGraphics();
		
		// Copy the input image into the output image
		g.drawImage(inImg, 0, 0, (ImageObserver) null);
		
		// Paint the frame around the output image
		g.setColor(Color.BLACK);
		int thickness = thicknessParam.getValue();
		for (int x=0, y=0, width=inImg.getWidth(), height=inImg.getHeight();
		     x<thickness;
		     x++, y++, width-=2, height-=2)
		{
			g.drawRect(x, y, width, height);
		}
	}
	
	public String toString() {
		return "Frame";
	}
	
	// ### PARAMETERIZED FILTER ###
	
	public FilterParam[] getParams() {
		return params;
	}
}